IconConfig class

单个图标配置

Constructors

IconConfig({required String url, required String fontAssetsPath})
IconConfig.fromYaml(YamlMap yaml)
从YAML配置创建IconConfig
factory

Properties

className ↔ String
类名,默认从icon_name获取
getter/setter pair
fontAssetsPath → String
字体资源路径
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
图标CSS文件URL
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited