icon2 class

icon2 icon font

to use these icons, import the font file:

import 'package:your_project/iconfont/icon2.dart';

then use in your widgets:

Icon(icon2.iconName)

Constructors

icon2()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

cart → const IconData
notification → const IconData