FontProcessor class
字体处理器,负责下载和处理字体文件
Constructors
- FontProcessor(IconConfig config)
Properties
- config → IconConfig
-
图标配置
final
- fontFamily ↔ String
-
字体名称
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
icons
↔ List<
IconInfo> -
图标列表
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
process(
) → Future< void> - 处理字体
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited