icon1 class
icon1 icon font
to use these icons, import the font file:
import 'package:your_project/iconfont/icon1.dart';
then use in your widgets:
Icon(icon1.iconName)
Constructors
- icon1()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited